@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2015-2017,2019-2022 Aurimas Cernius
+ * Copyright (C) 2013,2015-2017,2019-2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,54 +28,29 @@ namespace gnote {
 int MainWindow::s_use_client_side_decorations = -1;
 
 
-MainWindow *MainWindow::get_owning(Gtk::Widget & widget)
-{
-  Gtk::Container *container = widget.get_parent();
-  if(!container) {
-    return dynamic_cast<MainWindow*>(&widget);
-  }
-
-  Gtk::Container *cntr = container->get_parent();
-  while(cntr) {
-    container = cntr;
-    cntr = container->get_parent();
-  }
-
-  return dynamic_cast<MainWindow*>(container);
-}
-
-void MainWindow::present_in(MainWindow & win, const Note::Ptr & note)
+void MainWindow::present_in(MainWindow & win, Note & note)
 {
   win.present_note(note);
   win.present();
 }
 
-MainWindow *MainWindow::present_in_new_window(IGnote & g, const Note::Ptr & note)
+MainWindow & MainWindow::present_in_new_window(IGnote & g, Note & note)
 {
-  if(!note) {
-    return NULL;
-  }
-
   MainWindow & window = g.new_main_window();
   window.present_note(note);
   window.present();
-  return &window;
-
-  return NULL;
+  return window;
 }
 
-MainWindow *MainWindow::present_default(IGnote & g, const Note::Ptr & note)
+MainWindow & MainWindow::present_default(IGnote & g, Note & note)
 {
-  if(!note) {
-    return NULL;
-  }
-  if(note->has_window()) {
-    auto note_window = note->get_window();
+  if(note.has_window()) {
+    auto note_window = note.get_window();
     if(note_window->host()) {
       MainWindow *win = dynamic_cast<MainWindow*>(note_window->host());
       if(win) {
         win->present_note(note);
-        return win;
+        return *win;
       }
     }
   }
@@ -83,7 +58,7 @@ MainWindow *MainWindow::present_default(IGnote & g, const Note::Ptr & note)
   MainWindow & win = g.get_window_for_note();
   win.present_note(note);
   win.present();
-  return &win;
+  return win;
 }
 
 bool MainWindow::use_client_side_decorations(Preferences & prefs)
@@ -122,7 +97,6 @@ bool MainWindow::use_client_side_decorations(Preferences & prefs)
 
 
 MainWindow::MainWindow(Glib::ustring && title)
-  : m_close_on_esc(false)
 {
   set_title(std::move(title));
 }
