@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2015-2017,2019,2021-2022 Aurimas Cernius
+ * Copyright (C) 2013,2015-2017,2019,2021-2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,9 +37,9 @@ class MainWindow
   , public EmbeddableWidgetHost
 {
 public:
-  static void present_in(MainWindow & win, const Note::Ptr & note);
-  static MainWindow *present_in_new_window(IGnote & g, const Note::Ptr & note);
-  static MainWindow *present_default(IGnote & g, const Note::Ptr & note);
+  static void present_in(MainWindow & win, Note & note);
+  static MainWindow & present_in_new_window(IGnote & g, Note & note);
+  static MainWindow & present_default(IGnote & g, Note & note);
   static bool use_client_side_decorations(Preferences & prefs);
 
   explicit MainWindow(Glib::ustring && title);
@@ -51,11 +51,9 @@ public:
   virtual void close_window() = 0;
   virtual bool is_search() = 0;
 protected:
-  virtual void present_note(const Note::Ptr & note) = 0;
+  virtual void present_note(Note & note) = 0;
 private:
   static int s_use_client_side_decorations;
-
-  bool m_close_on_esc;
 };
 
 }
