@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2016,2019,2022-2023 Aurimas Cernius
+ * Copyright (C) 2012-2016,2019,2022-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -44,8 +44,13 @@ namespace gnote {
       on_note_opened();
       /* Connect these two signals here, because signal_opened won't emit for
        * opening already opened notes. */
-      window->signal_foregrounded.connect(sigc::mem_fun(*this, &NoteAddin::on_note_foregrounded));
-      window->signal_backgrounded.connect(sigc::mem_fun(*this, &NoteAddin::on_note_backgrounded));
+      window->signal_foregrounded.connect(sigc::mem_fun(*this, &NoteAddin::on_foregrounded));
+      window->signal_backgrounded.connect(sigc::mem_fun(*this, &NoteAddin::on_backgrounded));
+
+      // if already foreground, trigger that too
+      if(window->host()->is_foreground(*window)) {
+        on_foregrounded();
+      }
     }
   }
 
@@ -65,11 +70,11 @@ namespace gnote {
     on_note_opened();
     NoteWindow * window = get_window();
 
-    window->signal_foregrounded.connect(sigc::mem_fun(*this, &NoteAddin::on_note_foregrounded));
-    window->signal_backgrounded.connect(sigc::mem_fun(*this, &NoteAddin::on_note_backgrounded));
+    window->signal_foregrounded.connect(sigc::mem_fun(*this, &NoteAddin::on_foregrounded));
+    window->signal_backgrounded.connect(sigc::mem_fun(*this, &NoteAddin::on_backgrounded));
   }
 
-  void NoteAddin::on_note_foregrounded()
+  void NoteAddin::on_foregrounded()
   {
     auto host = get_window()->host();
     if(!host) {
@@ -85,14 +90,17 @@ namespace gnote {
         ERR_OUT("Action %s not found!", callback.first.c_str());
       }
     }
+
+    on_note_foregrounded();
   }
 
-  void NoteAddin::on_note_backgrounded()
+  void NoteAddin::on_backgrounded()
   {
     for(auto cid : m_action_callbacks_cids) {
       cid.disconnect();
     }
     m_action_callbacks_cids.clear();
+    on_note_backgrounded();
   }
 
   Gtk::Window *NoteAddin::get_host_window() const
