@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017,2019-2023 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 
 #include <map>
 #include <optional>
+#include <unordered_set>
 #include <vector>
 
 #include <glibmm/object.h>
@@ -31,6 +32,7 @@
 #include <sigc++/signal.h>
 
 #include "tag.hpp"
+#include "base/hash.hpp"
 #include "sharp/datetime.hpp"
 #include "sharp/xmlreader.hpp"
 #include "sharp/xmlwriter.hpp"
@@ -44,7 +46,7 @@ class NoteManagerBase;
 class NoteData
 {
 public:
-  typedef std::map<Glib::ustring, Tag::Ptr> TagMap;
+  typedef std::unordered_set<Glib::ustring, Hash<Glib::ustring>> TagSet;
 
   static const int s_noPosition;
 
@@ -127,11 +129,11 @@ public:
     {
       return m_height;
     }
-  const TagMap & tags() const
+  const TagSet& tags() const
     {
       return m_tags;
     }
-  TagMap & tags()
+  TagSet& tags()
     {
       return m_tags;
     }
@@ -150,7 +152,7 @@ private:
   int               m_selection_bound_pos;
   int               m_width, m_height;
 
-  TagMap m_tags;
+  TagSet m_tags;
 };
 
 
@@ -222,10 +224,9 @@ public:
   void rename_links(const Glib::ustring & old_title, const NoteBase & renamed);
   void remove_links(const Glib::ustring & old_title, const NoteBase & renamed);
   virtual void delete_note();
-  void add_tag(const Tag::Ptr &);
+  void add_tag(Tag&);
   virtual void remove_tag(Tag &);
-  void remove_tag(const Tag::Ptr &);
-  bool contains_tag(const Tag::Ptr &) const;
+  bool contains_tag(const Tag &) const;
 
   const Glib::ustring & file_path() const
     {
@@ -239,7 +240,7 @@ public:
   virtual void set_xml_content(Glib::ustring && xml);
   virtual Glib::ustring text_content();
   void load_foreign_note_xml(const Glib::ustring & foreignNoteXml, ChangeType changeType);
-  std::vector<Tag::Ptr> get_tags() const;
+  std::vector<Tag::Ref> get_tags() const;
   const NoteData & data() const;
   NoteData & data();
 
@@ -257,7 +258,7 @@ public:
   SavedHandler signal_saved;
   typedef sigc::signal<void(const NoteBase&, const Glib::ustring&)> RenamedHandler;
   RenamedHandler signal_renamed;
-  typedef sigc::signal<void(const NoteBase&, const Tag::Ptr&)> TagAddedHandler;
+  typedef sigc::signal<void(const NoteBase&, const Tag&)> TagAddedHandler;
   TagAddedHandler signal_tag_added;
   typedef sigc::signal<void(const NoteBase&, const Tag &)> TagRemovingHandler;
   TagRemovingHandler signal_tag_removing;
