@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017,2019,2023 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019,2023-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -45,12 +45,13 @@ public:
   static const char * NOTEBOOK_TAG_PREFIX;
 
   static Ptr create(NoteManagerBase& manager, const Glib::ustring& name, bool is_special = false);
-  static Ptr create(NoteManagerBase& manager, const Tag::Ptr& tag);
+  static Ptr create(NoteManagerBase& manager, const Tag &tag);
   Glib::ustring get_name() const
     { return m_name; }
   void set_name(const Glib::ustring &);
   virtual Glib::ustring get_normalized_name() const;
-  virtual Tag::Ptr    get_tag() const;
+  [[nodiscard]]
+  virtual Tag::ORef get_tag() const;
   Note::ORef find_template_note() const;
   virtual Note & get_template_note() const;
   Note & create_notebook_note();
@@ -67,20 +68,20 @@ public:
 protected:
   Notebook(NoteManagerBase &, const Glib::ustring &, bool is_special = false);
 
-  Tag::Ptr template_tag() const;
+  Tag::ORef template_tag() const;
   bool is_template_note(const Note&);
 
   NoteManagerBase & m_note_manager;
 private:
-  static Tag::Ptr s_template_tag;
+  static Glib::ustring s_template_tag;
 
-  Notebook(NoteManagerBase &, const Tag::Ptr &);
+  Notebook(NoteManagerBase &, const Tag&);
   Notebook(const Notebook &);
   Notebook & operator=(const Notebook &);
   Glib::ustring m_name;
   Glib::ustring m_normalized_name;
   Glib::ustring m_default_template_note_title;
-  Tag::Ptr    m_tag;
+  Glib::ustring m_tag;
 };
 
 }
