@@ -33,6 +33,19 @@
 
 namespace gnote {
 
+namespace {
+
+  void change_highlight(NoteTagTable &tag_table, const std::function<void(Gtk::TextTag &tag)> &closure)
+  {
+    if(auto tag = tag_table.lookup("highlight")) {
+      closure(*tag);
+    }
+    else {
+      ERR_OUT("Tag 'highlight' not found!");
+    }
+  }
+}
+
   NoteTag::NoteTag(Glib::ustring && tag_name, int flags)
     : Gtk::TextTag(tag_name)
     , m_element_name(std::move(tag_name))
@@ -253,8 +266,6 @@ namespace gnote {
   }
 
 
-  const char *NoteTagTable::HIGHLIGHT_COLOR = "#3584e4"; // From libadwaita: @accent_bg_color
-  const char *NoteTagTable::HIGHLIGHT_TEXT_COLOR = "#ffffff"; // From libadwaita: @accent_fg_color
   NoteTagTable::Ptr NoteTagTable::s_instance;
 
   void NoteTagTable::_init_common_tags()
@@ -270,6 +281,11 @@ namespace gnote {
       visited_link_color = style_ctx->get_color();
     }
 
+    m_preferences.signal_highlight_background_color_changed
+      .connect(sigc::mem_fun(*this, &NoteTagTable::on_highlight_background_setting_changed));
+    m_preferences.signal_highlight_foreground_color_changed
+      .connect(sigc::mem_fun(*this, &NoteTagTable::on_highlight_foreground_setting_changed));
+
     // Font stylings
 
     tag = NoteTag::create("centered", NoteTag::CAN_UNDO | NoteTag::CAN_GROW | NoteTag::CAN_SPELL_CHECK);
@@ -289,8 +305,8 @@ namespace gnote {
     add(tag);
 
     tag = NoteTag::create("highlight", NoteTag::CAN_UNDO | NoteTag::CAN_GROW | NoteTag::CAN_SPELL_CHECK);
-    tag->property_background() = HIGHLIGHT_COLOR;
-    tag->property_foreground() = HIGHLIGHT_TEXT_COLOR;
+    tag->property_background() = m_preferences.highlight_background_color();
+    tag->property_foreground() = m_preferences.highlight_foreground_color();
     add(tag);
 
     tag = NoteTag::create("find-match", NoteTag::CAN_SPELL_CHECK);
@@ -370,6 +386,19 @@ namespace gnote {
     m_url_tag = tag;
   }
 
+  void NoteTagTable::on_highlight_background_setting_changed()
+  {
+    change_highlight(*this, [this](Gtk::TextTag &tag) {
+      tag.property_background() = m_preferences.highlight_background_color();
+    });
+  }
+
+  void NoteTagTable::on_highlight_foreground_setting_changed()
+  {
+    change_highlight(*this, [this](Gtk::TextTag &tag) {
+      tag.property_foreground() = m_preferences.highlight_foreground_color();
+    });
+  }
 
   bool NoteTagTable::tag_is_serializable(const Glib::RefPtr<const Gtk::TextTag> & tag)
   {
