@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2013,2016-2017,2019-2022 Aurimas Cernius
+ * Copyright (C) 2010-2013,2016-2017,2019-2023 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -40,7 +40,6 @@
 #include "utils.hpp"
 
 #include "exporttohtmlnoteaddin.hpp"
-#include "exporttohtmldialog.hpp"
 #include "notenameresolver.hpp"
 
 #define STYLESHEET_NAME "exporttohtml.xsl"
@@ -80,24 +79,31 @@ void ExportToHtmlNoteAddin::on_note_opened()
 std::vector<gnote::PopoverWidget> ExportToHtmlNoteAddin::get_actions_popover_widgets() const
 {
   auto widgets = NoteAddin::get_actions_popover_widgets();
-  auto button = gnote::utils::create_popover_button("win.exporttohtml-export", _("Export to HTML…"));
-  widgets.push_back(gnote::PopoverWidget::create_for_note(gnote::EXPORT_TO_HTML_ORDER, button));
+  auto item = Gio::MenuItem::create(_("Export to HTML…"), "win.exporttohtml-export");
+  widgets.push_back(gnote::PopoverWidget::create_for_note(gnote::EXPORT_TO_HTML_ORDER, item));
   return widgets;
 }
 
 
 void ExportToHtmlNoteAddin::export_button_clicked(const Glib::VariantBase&)
 {
-  ExportToHtmlDialog dialog(ignote(), get_note()->get_title() + ".html");
-  int response = dialog.run();
-  Glib::ustring output_path = dialog.get_filename();
+  auto dialog = Gtk::make_managed<ExportToHtmlDialog>(ignote(), get_note().get_title() + ".html");
+  dialog->show();
+  dialog->signal_response().connect([this, dialog](int response) {
+    dialog->hide();
+    if(response != Gtk::ResponseType::OK) {
+      return;
+    }
 
-  if (response != Gtk::RESPONSE_OK) {
-    return;
-  }
+    export_dialog_response(*dialog);
+  });
+}
 
-  DBG_OUT("Exporting Note '%s' to '%s'...", get_note()->get_title().c_str(), 
-          output_path.c_str());
+
+void ExportToHtmlNoteAddin::export_dialog_response(ExportToHtmlDialog & dialog)
+{
+  Glib::ustring output_path = dialog.get_file()->get_path();
+  DBG_OUT("Exporting Note '%s' to '%s'...", get_note().get_title().c_str(), output_path.c_str());
 
   sharp::StreamWriter writer;
   Glib::ustring error_message;
@@ -107,8 +113,7 @@ void ExportToHtmlNoteAddin::export_button_clicked(const Glib::VariantBase&)
     sharp::file_delete(output_path);
 
     writer.init(output_path);
-    write_html_for_note (writer, get_note(), dialog.get_export_linked(), 
-                         dialog.get_export_linked_all());
+    write_html_for_note(writer, get_note(), dialog.get_export_linked(), dialog.get_export_linked_all());
 
     // Save the dialog preferences now that the note has
     // successfully been exported
@@ -118,9 +123,8 @@ void ExportToHtmlNoteAddin::export_button_clicked(const Glib::VariantBase&)
       sharp::Uri output_uri{Glib::ustring(output_path)};
       gnote::utils::open_url(*get_host_window(), "file://" + output_uri.get_absolute_uri());
     } 
-    catch (const Glib::Exception & ex) {
-      ERR_OUT(_("Could not open exported note in a web browser: %s"),
-               ex.what().c_str());
+    catch (const std::exception & ex) {
+      ERR_OUT(_("Could not open exported note in a web browser: %s"), ex.what());
 
       Glib::ustring detail = Glib::ustring::compose(
                                  // TRANSLATORS: %1%: boost format placeholder for the path
@@ -129,13 +133,14 @@ void ExportToHtmlNoteAddin::export_button_clicked(const Glib::VariantBase&)
 
       // Let the user know the note was saved successfully
       // even though showing the note in a web browser failed.
-      gnote::utils::HIGMessageDialog msg_dialog(
+      auto msg_dialog = Gtk::make_managed<gnote::utils::HIGMessageDialog>(
         get_host_window(),
         GTK_DIALOG_DESTROY_WITH_PARENT,
-        Gtk::MESSAGE_INFO, Gtk::BUTTONS_OK,
+        Gtk::MessageType::INFO, Gtk::ButtonsType::OK,
         _("Note exported successfully"),
         detail);
-      msg_dialog.run();
+      msg_dialog->show();
+      msg_dialog->signal_response().connect([msg_dialog](int) { msg_dialog->hide(); });
     }
   } 
 #if 0
@@ -161,12 +166,13 @@ void ExportToHtmlNoteAddin::export_button_clicked(const Glib::VariantBase&)
                             _("Could not save the file \"%1\""),
                             output_path.c_str());
 
-    gnote::utils::HIGMessageDialog msg_dialog(&dialog, 
+    auto msg_dialog = Gtk::make_managed<gnote::utils::HIGMessageDialog>(get_host_window(),
                                               GTK_DIALOG_DESTROY_WITH_PARENT,
-                                              Gtk::MESSAGE_ERROR, 
-                                              Gtk::BUTTONS_OK,
+                                              Gtk::MessageType::ERROR,
+                                              Gtk::ButtonsType::OK,
                                               msg, error_message);
-    msg_dialog.run();
+    msg_dialog->show();
+    msg_dialog->signal_response().connect([msg_dialog](int) { msg_dialog->hide(); });
   }
 }
 
@@ -219,21 +225,17 @@ sharp::XslTransform & ExportToHtmlNoteAddin::get_note_xsl()
 }
 
 
-
-
-void ExportToHtmlNoteAddin::write_html_for_note (sharp::StreamWriter & writer, 
-                                                 const gnote::Note::Ptr & note, 
-                                                 bool export_linked, 
-                                                 bool export_linked_all)
+void ExportToHtmlNoteAddin::write_html_for_note(sharp::StreamWriter & writer,
+  gnote::Note & note, bool export_linked, bool export_linked_all)
 {
   Glib::ustring s_writer;
-  s_writer = note->manager().note_archiver().write_string(note->data());
+  s_writer = note.manager().note_archiver().write_string(note.data());
   xmlDocPtr doc = xmlParseMemory(s_writer.c_str(), s_writer.bytes());
 
   sharp::XsltArgumentList args;
-  args.add_param ("export-linked", "", export_linked);
-  args.add_param ("export-linked-all", "", export_linked_all);
-  args.add_param ("root-note", "", gnote::utils::XmlEncoder::encode(note->get_title()));
+  args.add_param("export-linked", "", export_linked);
+  args.add_param("export-linked-all", "", export_linked_all);
+  args.add_param("root-note", "", gnote::utils::XmlEncoder::encode(note.get_title()));
 
   if(ignote().preferences().enable_custom_font()) {
     Glib::ustring font_face = ignote().preferences().custom_font_face();
@@ -243,7 +245,7 @@ void ExportToHtmlNoteAddin::write_html_for_note (sharp::StreamWriter & writer,
     args.add_param ("font", "", font);
   }
 
-  NoteNameResolver resolver(note->manager(), note);
+  NoteNameResolver resolver(note.manager(), note);
   get_note_xsl().transform(doc, args, writer, resolver);
 
   xmlFreeDoc(doc);
