@@ -153,29 +153,9 @@ namespace gnote {
     auto controller = Gtk::EventControllerKey::create();
     controller->signal_key_pressed().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_key_pressed), true);
     add_controller(controller);
+    register_shortcuts();
 
     g.signal_quit.connect(sigc::mem_fun(*this, &NoteRecentChanges::close_window));// to save size/pos
-
-    {
-      auto shortcuts = Gtk::ShortcutController::create();
-      auto trigger = Gtk::KeyvalTrigger::create(GDK_KEY_W, Gdk::ModifierType::CONTROL_MASK);
-      auto action = Gtk::NamedAction::create("win.close-tab");
-      auto shortcut = Gtk::Shortcut::create(trigger, action);
-      shortcuts->add_shortcut(shortcut);
-      action = Gtk::NamedAction::create("win.close-window");
-      trigger = Gtk::KeyvalTrigger::create(GDK_KEY_Q, Gdk::ModifierType::CONTROL_MASK);
-      shortcut = Gtk::Shortcut::create(trigger, action);
-      shortcuts->add_shortcut(shortcut);
-      trigger = Gtk::KeyvalTrigger::create(GDK_KEY_question, Gdk::ModifierType::CONTROL_MASK|Gdk::ModifierType::SHIFT_MASK);
-      action = Gtk::NamedAction::create("app.help-shortcuts");
-      shortcut = Gtk::Shortcut::create(trigger, action);
-      shortcuts->add_shortcut(shortcut);
-      add_controller(shortcuts);
-      action = Gtk::NamedAction::create("app.new-note");
-      trigger = Gtk::KeyvalTrigger::create(GDK_KEY_N, Gdk::ModifierType::CONTROL_MASK|Gdk::ModifierType::SHIFT_MASK);
-      shortcut = Gtk::Shortcut::create(trigger, action);
-      shortcuts->add_shortcut(shortcut);
-    }
   }
 
 
@@ -229,6 +209,43 @@ namespace gnote {
     register_callbacks();
   }
 
+  void NoteRecentChanges::register_shortcuts()
+  {
+    auto shortcuts = Gtk::ShortcutController::create();
+    auto trigger = Gtk::KeyvalTrigger::create(GDK_KEY_W, Gdk::ModifierType::CONTROL_MASK);
+    auto action = Gtk::NamedAction::create("win.close-tab");
+    auto shortcut = Gtk::Shortcut::create(trigger, action);
+    shortcuts->add_shortcut(shortcut);
+    action = Gtk::NamedAction::create("win.close-window");
+    trigger = Gtk::KeyvalTrigger::create(GDK_KEY_Q, Gdk::ModifierType::CONTROL_MASK);
+    shortcut = Gtk::Shortcut::create(trigger, action);
+    shortcuts->add_shortcut(shortcut);
+    trigger = Gtk::KeyvalTrigger::create(GDK_KEY_question, Gdk::ModifierType::CONTROL_MASK|Gdk::ModifierType::SHIFT_MASK);
+    action = Gtk::NamedAction::create("app.help-shortcuts");
+    shortcut = Gtk::Shortcut::create(trigger, action);
+    shortcuts->add_shortcut(shortcut);
+    action = Gtk::NamedAction::create("app.new-note");
+    trigger = Gtk::KeyvalTrigger::create(GDK_KEY_N, Gdk::ModifierType::CONTROL_MASK|Gdk::ModifierType::SHIFT_MASK);
+    shortcut = Gtk::Shortcut::create(trigger, action);
+    shortcuts->add_shortcut(shortcut);
+
+    for(int i = 0; i < 9; ++i) {
+      trigger = Gtk::KeyvalTrigger::create(GDK_KEY_1 + i, Gdk::ModifierType::ALT_MASK);
+      auto act = Gtk::CallbackAction::create([this, i](Gtk::Widget&, const Glib::VariantBase&){
+        m_embed_book.set_current_page(i);
+        return true;
+      });
+      shortcut = Gtk::Shortcut::create(trigger, act);
+      shortcuts->add_shortcut(shortcut);
+
+      trigger = Gtk::KeyvalTrigger::create(GDK_KEY_KP_1 + i, Gdk::ModifierType::ALT_MASK);
+      shortcut = Gtk::Shortcut::create(trigger, act);
+      shortcuts->add_shortcut(shortcut);
+    }
+
+    add_controller(shortcuts);
+  }
+
   void NoteRecentChanges::callbacks_changed()
   {
     unregister_callbacks();
