@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017,2019-2024 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019-2025 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,23 @@
 namespace gnote {
 namespace sync {
 
+namespace {
+
+  std::vector<Glib::ustring> get_updated_note_titles(const SyncServer::NoteUpdatesMap &note_updates)
+  {
+    std::vector<Glib::ustring> titles;
+    titles.reserve(note_updates.size());
+    for(auto & iter : note_updates) {
+      if(iter.second.m_title != "") {
+        titles.push_back(iter.second.m_title);
+      }
+    }
+
+    return titles;
+  }
+
+}
+
   SyncManager::SyncManager(IGnote & g, NoteManagerBase & m)
     : m_gnote(g)
     , m_note_manager(m)
@@ -155,24 +172,23 @@ namespace sync {
       f.addin = get_configured_sync_service();
       if(f.addin == NULL) {
         set_state(NO_CONFIGURED_SYNC_SERVICE);
-        DBG_OUT("GetConfiguredSyncService is null");
+        DBG_OUT("get_configured_sync_service is null");
         set_state(IDLE);
         return;
       }
 
-      DBG_OUT("SyncThread using SyncServiceAddin: %s", f.addin->name().c_str());
+      DBG_OUT("synchronization_thread using SyncServiceAddin: %s", f.addin->name().c_str());
 
       set_state(CONNECTING);
       try {
         server.reset(f.addin->create_sync_server());
         if(server == NULL)
-          throw std::logic_error("addin.CreateSyncServer () returned null");
+          throw std::logic_error("addin.create_sync_server() returned NULL");
       }
       catch(std::exception & e) {
         set_state(SYNC_SERVER_CREATION_FAILED);
         ERR_OUT(_("Exception while creating SyncServer: %s"), e.what());
         set_state(IDLE);
-        f.addin->post_sync_cleanup();// TODO: Needed?
         return;
         // TODO: Figure out a clever way to get the specific error up to the GUI
       }
@@ -190,60 +206,55 @@ namespace sync {
         return;
       }
       DBG_OUT("8");
-      int latestServerRevision = server->latest_revision();
-      int newRevision = latestServerRevision + 1;
+      const auto latest_server_revision = server->latest_revision();
+      const int new_revision = latest_server_revision + 1;
 
       // If the server has been wiped or reinitialized by another client
       // for some reason, our local manifest is inaccurate and could misguide
       // sync into erroneously deleting local notes, etc.  We reset the client
       // to prevent this situation.
-      Glib::ustring serverId = server->id();
-      if(m_client->associated_server_id() != serverId) {
+      const Glib::ustring server_id = server->id();
+      if(m_client->associated_server_id() != server_id) {
         m_client->reset();
-        m_client->associated_server_id(serverId);
+        m_client->associated_server_id(server_id);
       }
 
       m_client->begin_synchronization();
       set_state(PREPARE_DOWNLOAD);
 
       // Handle notes modified or added on server
-      DBG_OUT("Sync: GetNoteUpdatesSince rev %d", m_client->last_synchronized_revision());
-      std::map<Glib::ustring, NoteUpdate> noteUpdates = server->get_note_updates_since(m_client->last_synchronized_revision());
-      DBG_OUT("Sync: %d updates since rev %d", int(noteUpdates.size()), m_client->last_synchronized_revision());
+      DBG_OUT("Sync: get_note_updates_since rev %d", m_client->last_synchronized_revision());
+      const auto note_updates = server->get_note_updates_since(m_client->last_synchronized_revision());
+      DBG_OUT("Sync: %zu updates since rev %d", note_updates.size(), m_client->last_synchronized_revision());
 
       // Gather list of new/updated note titles
       // for title conflict handling purposes.
-      std::vector<Glib::ustring> noteUpdateTitles;
-      for(auto & iter : noteUpdates) {
-        if(iter.second.m_title != "") {
-          noteUpdateTitles.push_back(iter.second.m_title);
-        }
-      }
+      const std::vector<Glib::ustring> note_update_titles{get_updated_note_titles(note_updates)};
 
       // First, check for new local notes that might have title conflicts
       // with the updates coming from the server.  Prompt the user if necessary.
       // TODO: Lots of searching here and in the next foreach...
       //       Want this stuff to happen all at once first, but
       //       maybe there's a way to store this info and pass it on?
-      for(auto & iter : noteUpdates) {
+      for(auto & iter : note_updates) {
         if(find_note_by_uuid(iter.second.m_uuid)) {
-          auto existingNote = note_mgr().find(iter.second.m_title);
-          if(existingNote && !iter.second.basically_equal_to(existingNote.value())) {
+          auto existing_note = note_mgr().find(iter.second.m_title);
+          if(existing_note && !iter.second.basically_equal_to(existing_note.value())) {
             DBG_OUT("Sync: Early conflict detection for '%s'", iter.second.m_title.c_str());
             if(m_sync_ui != 0) {
-              m_sync_ui->note_conflict_detected(existingNote.value(), iter.second, noteUpdateTitles);
+              m_sync_ui->note_conflict_detected(existing_note.value(), iter.second, note_update_titles);
             }
           }
         }
       }
 
-      if(noteUpdates.size() > 0)
+      if(note_updates.size() > 0)
         set_state(DOWNLOADING);
 
       // TODO: Figure out why GUI doesn't always update smoothly
 
       // Process updates from the server; the bread and butter of sync!
-      for(auto & iter : noteUpdates) {
+      for(auto & iter : note_updates) {
         auto existing_note = find_note_by_uuid(iter.second.m_uuid);
 
         if(!existing_note) {
@@ -271,11 +282,11 @@ namespace sync {
             DBG_OUT("SyncManager: Content conflict in note update for note '%s'", iter.second.m_title.c_str());
             // Note already exists locally, but has been modified since last sync; prompt user
             if(m_sync_ui != 0) {
-              m_sync_ui->note_conflict_detected(existing, iter.second, noteUpdateTitles);
+              m_sync_ui->note_conflict_detected(existing, iter.second, note_update_titles);
             }
 
-            if(auto existingNote = find_note_by_uuid(iter.second.m_uuid)) {
-              update_note_in_main_thread(existingNote.value(), iter.second);
+            if(auto existing_note = find_note_by_uuid(iter.second.m_uuid)) {
+              update_note_in_main_thread(existing_note.value(), iter.second);
             }
             else {
               // Note has been deleted or okay'd for overwrite
@@ -298,21 +309,15 @@ namespace sync {
       // and upload new or modified ones to the server
       std::vector<NoteBase::Ref> new_or_modified_notes;
       note_mgr().for_each([this, &new_or_modified_notes](NoteBase & note) {
-        if(m_client->get_revision(note) == -1) {
-          // This is a new note that has never been synchronized to the server
-          // TODO: *OR* this is a note that we lost revision info for!!!
-          // TODO: Do the above NOW!!! (don't commit this dummy)
-          note_save(note);
-          new_or_modified_notes.push_back(note);
-          if(m_sync_ui != 0)
-            m_sync_ui->note_synchronized_th(note.get_title(), UPLOAD_NEW);
-        }
-        else if(m_client->get_revision(note) <= m_client->last_synchronized_revision()
-                && note.metadata_change_date() > m_client->last_sync_date()) {
+        // This is a new note that has never been synchronized to the server
+        bool new_note = m_client->get_revision(note) == -1;
+        bool modified = m_client->get_revision(note) <= m_client->last_synchronized_revision()
+          && note.metadata_change_date() > m_client->last_sync_date();
+        if(new_note || modified) {
           note_save(note);
           new_or_modified_notes.push_back(note);
           if(m_sync_ui != 0) {
-            m_sync_ui->note_synchronized_th(note.get_title(), UPLOAD_MODIFIED);
+            m_sync_ui->note_synchronized_th(note.get_title(), new_note? UPLOAD_NEW : UPLOAD_MODIFIED);
           }
         }
       });
@@ -324,24 +329,25 @@ namespace sync {
       }
 
       // Handle notes deleted on client
-      std::vector<Glib::ustring> locallyDeletedUUIDs;
+      std::vector<Glib::ustring> locally_deleted_uuids;
       auto all_note_uuids = server->get_all_note_uuids();
       for(auto & iter : all_note_uuids) {
         if(!find_note_by_uuid(iter)) {
-          locallyDeletedUUIDs.push_back(iter);
+          locally_deleted_uuids.push_back(iter);
           if(m_sync_ui != 0) {
-            Glib::ustring deletedTitle = iter;
-            auto deleted_note_titles = m_client->deleted_note_titles();
-            if(deleted_note_titles.find(iter) != deleted_note_titles.end()) {
-              deletedTitle = deleted_note_titles[iter];
+            Glib::ustring deleted_title = iter;
+            auto &deleted_note_titles = m_client->deleted_note_titles();
+            auto deleted_note = deleted_note_titles.find(iter);
+            if(deleted_note != deleted_note_titles.end()) {
+              deleted_title = deleted_note->second;
             }
-            m_sync_ui->note_synchronized_th(deletedTitle, DELETE_FROM_SERVER);
+            m_sync_ui->note_synchronized_th(deleted_title, DELETE_FROM_SERVER);
           }
         }
       }
-      if(locallyDeletedUUIDs.size() > 0) {
+      if(locally_deleted_uuids.size() > 0) {
         set_state(DELETE_SERVER_NOTES);
-        server->delete_notes(locallyDeletedUUIDs);
+        server->delete_notes(locally_deleted_uuids);
       }
 
       set_state(COMMITTING_CHANGES);
@@ -350,7 +356,7 @@ namespace sync {
         // Apply this revision number to all new/modified notes since last sync
         // TODO: Is this the best place to do this (after successful server commit)
         for(NoteBase & iter : new_or_modified_notes) {
-          m_client->set_revision(iter, newRevision);
+          m_client->set_revision(iter, new_revision);
         }
         set_state(SUCCEEDED);
       }
@@ -359,7 +365,7 @@ namespace sync {
         // TODO: Figure out a way to let the GUI know what exactly failed
       }
 
-      // This should be equivalent to newRevision
+      // This should be equivalent to new_revision
       m_client->last_synchronized_revision(server->latest_revision());
 
       m_client->last_sync_date(Glib::DateTime::create_now_utc());
@@ -397,14 +403,6 @@ namespace sync {
   }
 
 
-  void SyncManager::resolve_conflict(SyncTitleConflictResolution resolution)
-  {
-    if(m_sync_thread) {
-      m_conflict_resolution = resolution;
-    }
-  }
-
-
   void SyncManager::handle_note_buffer_changed(NoteBase &)
   {
     // Note changed, iff a sync is coming up we kill the
