@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013,2017,2019 Aurimas Cernius
+ * Copyright (C) 2012-2013,2017,2019,2022-2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ namespace sync {
     : public AbstractAddin
   {
   public:
-    typedef sigc::slot<void> EventHandler;
+    typedef sigc::slot<void()> EventHandler;
     static const char * IFACE_NAME;
 
     SyncServiceAddin()
@@ -56,17 +56,17 @@ namespace sync {
       }
     virtual SyncServer *create_sync_server() = 0;
     virtual void post_sync_cleanup() = 0;
-    virtual Gtk::Widget *create_preferences_control(EventHandler requiredPrefChanged) = 0;
-    virtual bool save_configuration(const sigc::slot<void, bool, Glib::ustring> & on_saved) = 0;
+    virtual Gtk::Widget *create_preferences_control(Gtk::Window & parent, EventHandler requiredPrefChanged) = 0;
+    virtual bool save_configuration(const sigc::slot<void(bool, Glib::ustring)> & on_saved) = 0;
     virtual void reset_configuration() = 0;
-    virtual bool is_configured() = 0;
-    virtual bool are_settings_valid()
+    virtual bool is_configured() const = 0;
+    virtual bool are_settings_valid() const
       {
         return true;
       }
-    virtual Glib::ustring name() = 0;
-    virtual Glib::ustring id() = 0;
-    virtual bool is_supported() = 0;
+    virtual Glib::ustring name() const = 0;
+    virtual Glib::ustring id() const = 0;
+    virtual bool is_supported() const = 0;
     virtual void shutdown () = 0;
     virtual bool initialized () = 0;
   protected:
