@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013-2014,2017,2019,2021-2022 Aurimas Cernius
+ * Copyright (C) 2011,2013-2014,2017,2019,2021-2022,2024 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -31,30 +31,8 @@
 
 namespace gnote {
 
-  namespace {
-    int compare_tags_sort_func (const Gtk::TreeIter & a, 
-                                const Gtk::TreeIter & b)
-    {
-      Tag::Ptr tag_a;
-      a->get_value(0, tag_a);
-      Tag::Ptr tag_b;
-      b->get_value(0, tag_b);
-
-      if (!tag_a || !tag_b)
-        return 0;
-
-      return strcmp(tag_a->normalized_name().c_str(), 
-                    tag_b->normalized_name().c_str());
-    }
-  }
-
   TagManager::TagManager()
-    :  m_tags(Gtk::ListStore::create(m_columns))
-    ,  m_sorted_tags(Gtk::TreeModelSort::create(m_tags))
   {
-    m_sorted_tags->set_sort_func (0, sigc::ptr_fun(&compare_tags_sort_func));
-    m_sorted_tags->set_sort_column(0, Gtk::SORT_ASCENDING);
-    
   }
 
 
@@ -62,7 +40,7 @@ namespace gnote {
   // Return an existing tag for the specified tag name.  If no Tag exists
   // null will be returned.
   // </summary>
-  Tag::Ptr TagManager::get_tag (const Glib::ustring & tag_name) const
+  Tag::ORef TagManager::get_tag(const Glib::ustring & tag_name) const
   {
     if (tag_name.empty())
       throw sharp::Exception("TagManager.GetTag () called with a null tag name.");
@@ -77,23 +55,24 @@ namespace gnote {
       std::lock_guard<std::mutex> lock(m_locker);
       auto iter = m_internal_tags.find(normalized_tag_name);
       if(iter != m_internal_tags.end()) {
-        return iter->second;
+        return *iter->second;
       }
-      return Tag::Ptr();
-    }
-    auto iter = m_tag_map.find(normalized_tag_name);
-    if (iter != m_tag_map.end()) {
-      Gtk::TreeIter tree_iter = iter->second;
-      return (*tree_iter)[m_columns.m_tag];
+      return Tag::ORef();
     }
 
-    return Tag::Ptr();
+    for(auto &tag : m_tags) {
+      if(tag->normalized_name() == normalized_tag_name) {
+        return *tag;
+      }
+    }
+
+    return Tag::ORef();
   }
   
   // <summary>
   // Same as GetTag () but will create a new tag if one doesn't already exist.
   // </summary>
-  Tag::Ptr TagManager::get_or_create_tag(const Glib::ustring & tag_name)
+  Tag &TagManager::get_or_create_tag(const Glib::ustring & tag_name)
   {
     if (tag_name.empty())
       throw sharp::Exception ("TagManager.GetOrCreateTag () called with a null tag name.");
@@ -108,36 +87,28 @@ namespace gnote {
       std::lock_guard<std::mutex> lock(m_locker);
       auto iter = m_internal_tags.find(normalized_tag_name);
       if(iter != m_internal_tags.end()) {
-        return iter->second;
+        return *iter->second;
       }
       else {
-        Tag::Ptr t(std::make_shared<Tag>(Glib::ustring(tag_name)));
-        m_internal_tags [ t->normalized_name() ] = t;
-        return t;
+        TagPtr t(new Tag(Glib::ustring(tag_name)));
+        Tag& ret = *t;
+        m_internal_tags[ret.normalized_name()] = std::move(t);
+        return ret;
       }
     }
-    Gtk::TreeIter iter;
-    bool tag_added = false;
-    Tag::Ptr tag = get_tag (normalized_tag_name);
-    if (!tag) {
+    auto tag = get_tag(normalized_tag_name);
+    if(!tag) {
       std::lock_guard<std::mutex> lock(m_locker);
 
-      tag = get_tag (normalized_tag_name);
-      if (!tag) {
-        tag = std::make_shared<Tag>(sharp::string_trim(tag_name));
-        iter = m_tags->append ();
-        (*iter)[m_columns.m_tag] = tag;
-        m_tag_map [tag->normalized_name()] = iter;
-
-        tag_added = true;
+      tag = get_tag(normalized_tag_name);
+      if(!tag) {
+        TagPtr tg(new Tag(sharp::string_trim(tag_name)));
+        tag = *tg;
+        m_tags.emplace_back(std::move(tg));
       }
     }
 
-    if (tag_added) {
-      m_signal_tag_added(tag, iter);
-    }
-
-    return tag;
+    return *tag;
   }
     
   /// <summary>
@@ -150,9 +121,12 @@ namespace gnote {
   /// <returns>
   /// A <see cref="Tag"/>
   /// </returns>
-  Tag::Ptr TagManager::get_system_tag (const Glib::ustring & tag_name) const
+  Tag::ORef TagManager::get_system_tag (const Glib::ustring & tag_name) const
   {
-    return get_tag(Tag::SYSTEM_TAG_PREFIX + tag_name);
+    if(auto tag = get_tag(Tag::SYSTEM_TAG_PREFIX + tag_name)) {
+      return *tag;
+    }
+    return Tag::ORef();
   }
     
   /// <summary>
@@ -165,7 +139,7 @@ namespace gnote {
   /// <returns>
   /// A <see cref="Tag"/>
   /// </returns>
-  Tag::Ptr TagManager::get_or_create_system_tag (const Glib::ustring & tag_name)
+  Tag &TagManager::get_or_create_system_tag(const Glib::ustring & tag_name)
   {
     return get_or_create_tag(Tag::SYSTEM_TAG_PREFIX + tag_name);
   }
@@ -175,63 +149,41 @@ namespace gnote {
     // This will remove the tag from every note that is currently tagged
     // and from the main list of tags.
     // </summary>
-  void TagManager::remove_tag (const Tag::Ptr & tag)
+  void TagManager::remove_tag(Tag &tag)
   {
-    if (!tag)
-      throw sharp::Exception ("TagManager.RemoveTag () called with a null tag");
-
-    if(tag->is_property() || tag->is_system()){
-      std::lock_guard<std::mutex> lock(m_locker);
-
-      m_internal_tags.erase(tag->normalized_name());
-    }
-    bool tag_removed = false;
-    auto map_iter = m_tag_map.find(tag->normalized_name());
-    if (map_iter != m_tag_map.end()) {
-      std::lock_guard<std::mutex> lock(m_locker);
-
-      map_iter = m_tag_map.find(tag->normalized_name());
-      if (map_iter != m_tag_map.end()) {
-        Gtk::TreeIter iter = map_iter->second;
-        if (!m_tags->erase(iter)) {
-          DBG_OUT("TagManager: Removed tag: %s", tag->normalized_name().c_str());
-        } 
-        else { 
-          // FIXME: For some really weird reason, this block actually gets called sometimes!
-          DBG_OUT("TagManager: Call to remove tag from ListStore failed: %s", tag->normalized_name().c_str());
-        }
-
-        m_tag_map.erase(map_iter);
-        DBG_OUT("Removed TreeIter from tag_map: %s", tag->normalized_name().c_str());
-        tag_removed = true;
-
-        auto notes = tag->get_notes();
-        for(NoteBase *note_iter : notes) {
-          note_iter->remove_tag(tag);
-        }
-      }
+    auto tag_name = tag.normalized_name();
+    std::lock_guard<std::mutex> lock(m_locker);
+    if(tag.is_property() || tag.is_system()) {
+      m_internal_tags.erase(tag_name);
     }
 
-    if (tag_removed) {
-      m_signal_tag_removed(tag->normalized_name());
+    auto iter = std::find_if(m_tags.begin(), m_tags.end(), [&tag](const TagPtr &t) { return t.get() == &tag; });
+    if(iter != m_tags.end()) {
+      m_tags.erase(iter);
+      DBG_OUT("TagManager: Removed tag: %s", tag_name.c_str());
+    }
+    else {
+      // FIXME: For some really weird reason, this block actually gets called sometimes!
+      DBG_OUT("TagManager: Call to remove tag from ListStore failed: %s", tag_name.c_str());
+    }
+
+    auto notes = tag.get_notes();
+    for(NoteBase *note_iter : notes) {
+      note_iter->remove_tag(tag);
     }
   }
   
-  std::vector<Tag::Ptr> TagManager::all_tags() const
+  std::vector<Tag::Ref> TagManager::all_tags() const
   {
-    std::vector<Tag::Ptr> tags;
-
+    std::vector<Tag::Ref> tags;
+    tags.reserve(m_internal_tags.size() + m_tags.size());
     // Add in the system tags first
-    tags = sharp::map_get_values(m_internal_tags);
-
-    // Now all the other tags
-    for(TagMap::const_iterator iter = m_tag_map.begin();
-        iter != m_tag_map.end(); ++iter) {
-      Tag::Ptr tag;
-      iter->second->get_value(0, tag);      
-      tags.push_back(tag);
+    for(auto &tag : m_internal_tags) {
+      tags.emplace_back(*tag.second);
+    }
+    for(auto &tag : m_tags) {
+      tags.emplace_back(*tag);
     }
-
     return tags;
   }
 
