@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2014,2017-2019 Aurimas Cernius
+ * Copyright (C) 2014,2017-2019,2024 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,14 +29,15 @@ class TagManager
   : public gnote::ITagManager
 {
 public:
-  virtual gnote::Tag::Ptr get_tag(const Glib::ustring & tag_name) const override;
-  virtual gnote::Tag::Ptr get_or_create_tag(const Glib::ustring &) override;
-  virtual gnote::Tag::Ptr get_system_tag(const Glib::ustring & tag_name) const override;
-  virtual gnote::Tag::Ptr get_or_create_system_tag(const Glib::ustring & name) override;
-  virtual void remove_tag(const gnote::Tag::Ptr & tag) override;
-  virtual std::vector<gnote::Tag::Ptr> all_tags() const override;
+  gnote::Tag::ORef get_tag(const Glib::ustring & tag_name) const override;
+  gnote::Tag &get_or_create_tag(const Glib::ustring &) override;
+  gnote::Tag::ORef get_system_tag(const Glib::ustring & tag_name) const override;
+  gnote::Tag &get_or_create_system_tag(const Glib::ustring & name) override;
+  void remove_tag(gnote::Tag &tag) override;
+  std::vector<gnote::Tag::Ref> all_tags() const override;
 private:
-  std::map<Glib::ustring, gnote::Tag::Ptr> m_tags;
+  typedef std::unique_ptr<gnote::Tag> TagPtr;
+  std::vector<TagPtr> m_tags;
 };
 
 }
